#! /bin/bash

. /opt/artixcs-mysql-dump/artixcs-mysql-dump.conf

echo "user=$user"
echo "passwd=$passwd"
echo "backupDir=$backupDir"
echo "useCompress=$useCompress"
echo "incrementalDays=${incrementalDays}"

logDir="/var/log/artix/artixcs-mysql-dump"
logFile="${logDir}/dump.log"
logReport="${logDir}/dump-report.log"

# если нет директории для логов, то создадим ее
[ ! -d $logDir ] && mkdir -p $logDir

# если не указана директория, в которую требуется сохранять бэкапы, то запишем ошибку и не будем выполнять бэкап
if [[ -z "$backupDir" ]]; then
    echo "$(date +%y.%m.%d_%H:%M:%S) Backup is failed" | tee -a ${logReport}
    echo "$(date +%y.%m.%d_%H:%M:%S) Error: param backupDir is empty" | tee -a ${logFile}
    exit 10
fi

# подготовка списка опций для создания бэкапа
backupOptions="--backup --user=${user} --password=${passwd}"
if [[ "$useCompress" = 'true' ]]; then
    backupOptions="${backupOptions} --compress --compress-threads=4"
fi;

# если нет директории backupDir, то создадим ее
[ ! -d $backupDir ] && mkdir -p $backupDir


# если директория с полным дампом уже есть, в ней есть файлы и эта директория старше incrementalDays, то переименуем эту директорию и сделаем новый полный бэкап
if [[ -d "${backupDir}/full" ]] && [[ "$(ls -A ${backupDir}/full)" ]] && [[ $(find ${backupDir}/full -maxdepth 0 -type d -mtime +${incrementalDays} | wc -l) -gt 0 ]]; then
    echo "$(date +%y.%m.%d_%H:%M:%S) move ${backupDir}/* to ${backupDir}/backup/" > $logFile
    mkdir -p $backupDir/backup
    mv ${backupDir}/* ${backupDir}/backup/
    rm -rf ${logReport}
fi

# если директория с полным дампом уже есть и в ней есть файлы, то создадим инкрементальный дамп
targetDir=${backupDir}/full
if [[ -d "${backupDir}/full" ]] && [[ "$(ls -A ${backupDir}/full)" ]]; then
    lastIncrementDir=$(find ${backupDir} -maxdepth 1 -name 'increment*' -type d | sort -n | tail -1)
    if [[ -z "${lastIncrementDir}" ]]; then
        lastIncrementDir=${backupDir}/full
    fi
    targetDir=${backupDir}/increment_$(date +%y%m%d%H%M%S)
    backupOptions="${backupOptions} --incremental-basedir=${lastIncrementDir}"
fi
echo "$(date +%y.%m.%d_%H:%M:%S) xtrabackup ${backupOptions} --target-dir=${targetDir}" >> $logFile
xtrabackup ${backupOptions} --target-dir=${targetDir} >> $logFile 2>&1
if [ $? -ne 0 ]; then
    echo "$(date +%y.%m.%d_%H:%M:%S) Backup is failed" | tee -a ${logReport}
else
    echo "$(date +%y.%m.%d_%H:%M:%S) Backup completed successfully!" | tee -a ${logReport}
    rm -rf ${backupDir}/backup
fi
